# Changelog

Semantic Versioning

## v0.13 Insomniac Mosquitoes

Upgrades the storage format, and optimizes memory usage.

## v0.12 Noisy Katydids, March 3, 2021

Batch transaction signatures verification with transaction version 2.

## v0.11 Diligent Hoverflies, Feb 21, 2021

Fair mint distributions based on node works.

## v0.10 Rolling Spiders, Feb 1, 2021

Rolling nodes removal.

## v0.9 Fierce Grasshoppers, Sep 1, 2020

Parallel graph chain loops make the snapshot validation faster.

## v0.8 Soft Soldier Beetles, Jun 2, 2020

New configuration file format, final kernel snapshot validation, storage optimization and some minor fixes.

## v0.7 Exhilarating Dragonflies, Mar 9, 2020

Update the archive only mode, to allow archive node or start an archive only node, set the `consensus-only` option to `false` in config.json.

## v0.6 Serene Ladybugs, Feb 11, 2020

This release updates the underlying database to badger v2, adds Bitcoin domain, adds more snapshot validations, and some new helper commands.

## v0.5 Praying Mantis, Jul 25, 2019

This release enables compact Schnorr Signatures for Kernel snapshots.

## v0.4 Silent Butterflies, May 26, 2019

This release mainly improves the transport layer.

## v0.3 Charming Bees, May 12, 2019

This release welcomes all nodes to join the Mixin Kernel network freely.

## v0.2 Bustling Ants, Apr 10, 2019

This is the first release which enables asset withdrawal, soon people will be able to join as a Mixin Kernel node freely.

## v0.1 Genesis Main Net, Feb 27, 2019

This is the very first Mixin Network genesis main net release. For security concerns, peer connections and domain functions are limited.
